import React from 'react';
import { AutoComplete, Switch, Tabs, Table, Icon, Tooltip, Modal, Popover, message, Spin, Upload, Input, InputNumber, Select, DatePicker, Button, Radio, Form, Cascader, Tag } from 'antd';
import moment from 'moment';
import './techDemand.less';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import { IndustryObject, getIndustryCategory } from '../../DicIndustryList.js';
import { getTechField } from '../../DicTechFieldList.js';
import { beforeUploadFile, getTechAuditStatus, splitUrl, companySearch, getDemandType, getAchievementCategory,beforeUpload, getBase64 } from '../../tools.js';
import throttle from '../../throttle.js';

const KeyWordTagGroup = React.createClass({
    getInitialState() {
        return {
            tags: [],
            inputVisible: false,
            inputValue: ''
        };
    },
    handleClose(removedTag) {
        const tags = this.state.tags.filter(tag => tag !== removedTag);
        this.props.tagsArr(tags);
        this.setState({ tags });
    },
    showInput() {
        this.setState({ inputVisible: true }, () => this.input.focus());
    },
    handleInputChange(e) {
        this.setState({ inputValue: e.target.value });
    },
    handleInputConfirm() {
        const state = this.state;
        const inputValue = state.inputValue;
        let tags = state.tags;
        if (inputValue && tags.indexOf(inputValue) === -1 && inputValue.replace(/(^\s*)|(\s*$)/g, "").length != 0) {
            tags = [...tags, inputValue.replace(/(^\s*)|(\s*$)/g, "")];
        }
        this.props.tagsArr(tags);
        this.setState({
            tags,
            inputVisible: false,
            inputValue: '',
        });
    },
    componentWillMount() {
        this.state.tags = this.props.keyWordArr;
    },
    componentWillReceiveProps(nextProps) {
        if (this.props.keyWordArr != nextProps.keyWordArr) {
            this.state.tags = nextProps.keyWordArr;
        };
    },
    render() {
        const { tags, inputVisible, inputValue } = this.state;
        return (
            <div className="keyWord-tips">
                {tags.map((tag, index) => {
                    const isLongTag = tag.length > 10;
                    const tagElem = (
                        <Tag key={tag} closable={index !== -1} afterClose={() => this.handleClose(tag)}>
                            {isLongTag ? `${tag.slice(0, 10)}...` : tag}
                        </Tag>
                    );
                    return isLongTag ? <Tooltip title={tag}>{tagElem}</Tooltip> : tagElem;
                })}
                {inputVisible && (
                    <Input
                        ref={input => this.input = input}
                        type="text"
                        style={{ width: 78 }}
                        value={inputValue}
                        onChange={this.handleInputChange}
                        onBlur={this.handleInputConfirm}
                        onPressEnter={this.handleInputConfirm}
                    />
                )}
                {!inputVisible && <Button className="addtips" type="dashed" disabled={tags.length > 9 ? true : false} onClick={this.showInput}>+ 新关键词</Button>}
            </div>
        );
    }
});

const PicturesWall = React.createClass({
    getInitialState() {
        return {
            previewVisible: false,
            previewImage: '',
            fileList: [],
        }
    },
    handleCancel() {
        this.setState({ previewVisible: false })
    },
    handlePreview(file) {
        this.setState({
            previewImage: file.url || file.thumbUrl,
            previewVisible: true,
        });
    },
    handleChange(info) {
        let fileList = info.fileList;
        this.setState({ fileList });
        this.props.fileList(fileList);
    },
    componentWillReceiveProps(nextProps) {
        this.state.fileList = nextProps.pictureUrl;
    },
    render() {
        const { previewVisible, previewImage, fileList } = this.state;
        const uploadButton = (
            <div>
                <Icon type="plus" />
                <div className="ant-upload-text">点击上传</div>
            </div>
        );
        return (
            <div className="clearfix">
                <Upload
                    action={globalConfig.context + "/api/admin/demand/uploadPicture"}                                      
                    data={{ 'sign': this.props.pictureSign, 'uid': this.props.uid}}
                    listType="picture-card"
                    fileList={fileList}
                    onPreview={this.handlePreview}
                    onChange={this.handleChange} >
                    {fileList.length >= 5 ? null : uploadButton}
                </Upload>
                <Modal maskClosable={false} visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                    <img alt="example" style={{ width: '100%' }} src={previewImage} />
                </Modal>
            </div>
        );
    }
});

const DemandDetailShow = Form.create()(React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false,
            contactsObj: {},
            salesmanObj: {},
            data: {},
            tags: [],
            pictureUrl: [],
            coverImg: []           
        };
    },
    loadData(id, detailApiUrl,dataCategory) {
    	this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + detailApiUrl,
            data: {
                id: id,
                dataCategory:dataCategory?dataCategory:this.props.data.dataCategory
            },
            success: function (data) {
            	
                let thisData = data.data;              
                if (!thisData) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                    thisData = {};
                };
                this.setState({
                    data: thisData,
                    switchValue: Boolean(!thisData.employerId),
                    radios: thisData.hot == '1' ? true : false,
                    tags: thisData.keyword ? (thisData.keyword.replace(/(，|、)/g, ",")).split(',') : [],
                    pictureUrl: thisData.pictureUrl ? splitUrl(thisData.pictureUrl, ',', globalConfig.avatarHost + '/upload') : [],
                    coverImg: thisData.coverImg ? splitUrl(thisData.coverImg, ',', globalConfig.avatarHost + '/upload') : []
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getContactsList(theUid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/getContacts",
            data: {
                uid: theUid
            },
            success: function (data) {
                let theOption = [];
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    this.setState({
                        contactsObj: data.data
                    });
                };
            }.bind(this),
        });
    },
    offShelf() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/demand/offShelf",
            data: { "id": this.props.data.id }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('撤销成功！');
                this.props.handleOk();
            } else {
                message.warning(data.error[0].message);
            };
            this.setState({
                loading: false,
                releaseSubmitVisible: false
            });
        }.bind(this));
    },
    modifyBroker() {
        this.props.form.validateFields((err, values) => {
            if (!err) {
                this.setState({
                    loading: true
                });
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + '/api/admin/audit/modifyDemandTechBroker',
                    data: {
                        id: this.props.data.id,
                        techBrokerId: values.modifyTechBrokerId
                    }
                }).done(function (data) {
                    this.state.auditStatus = 0;
                    this.setState({
                        loading: false
                    });
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    } else {
                        message.success('保存成功！');
                        this.props.handleOk();
                    };
                }.bind(this));
            }
        });
    },
    formSubmit() {
        this.props.form.validateFields((err, values) => {
            if (values.auditStatus == 3 && !values.techBrokerId) {
                message.warning('必须选择一个技术经纪人！');
                return
            };
            if (!err) {
                this.setState({
                    loading: true
                });
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + '/api/admin/audit/demand',
                    data: {
                        id: this.props.data.id,
                        techBroderId: values.techBrokerId,
                        auditStatus: values.auditStatus
                    }
                }).done(function (data) {
                    this.state.auditStatus = 0;
                    if (!data.error.length) {
                        message.success('保存成功！');
                        this.setState({ formSubmitVisible: false });
                        this.props.handleOk();
                    } else {
                        message.warning(data.error[0].message);
                        this.setState({
                            loading: false,
                        });
                    }
                }.bind(this));
            }
        });
    },
    handleSubmit(e) {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            if (values.auditStatus == 4) {
                this.setState({
                    formSubmitVisible: true
                });
            } else {
                this.formSubmit();
            };
        });
    },
    buildMatchList() {
        this.setState({
            buttonLoading: true
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + '/api/admin/demand/matchAchievement',
            data: {
                id: this.props.data.id,
            }
        }).done(function (data) {
            this.setState({
                buttonLoading: false
            });
            if (!data.error.length) {
                message.success('匹配完成！匹配到' + data.data + '条记录');
            } else {
                message.warning(data.error[0].message);
            };
        }.bind(this));
    },
    componentWillMount() {
        this.loadData(this.props.data.id, this.props.detailApiUrl);
        if (this.props.data.employerId && this.props.data.dataCategory) {
            this.getContactsList(this.props.data.employerId);
        };
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.loadData(nextProps.data.id, nextProps.detailApiUrl,nextProps.data.dataCategory);
            if (nextProps.data.employerId && nextProps.data.dataCategory) {
                this.getContactsList(nextProps.data.employerId);
            };
            this.props.form.resetFields();
        };
    },
    render() {
        const theData = this.state.data || {};
        const { getFieldDecorator } = this.props.form;
        const FormItem = Form.Item
        const formItemLayout = {
            labelCol: { span: 6 },
            wrapperCol: { span: 12 },
        };
        return (
            <Form horizontal onSubmit={this.handleSubmit} id="demand-form">
                <Spin spinning={this.state.loading}>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="编号" >
                            <span>{theData.serialNumber}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求名称" >
                            <span>{theData.name}</span>
                        </FormItem>                       
                    </div>
                    <div>
                    <FormItem className="half-item"
                            {...formItemLayout}
                            label="精品需求" >
                            {(() => {
                                switch (theData.boutique) {
                                    case "0":
                                        return <span>否</span>;
                                    case "1":
                                        return <span>是</span>;
                                }
                            })()}
                        </FormItem>
                    </div>                    
                     {this.state.radios==true ? <div>
                    	<FormItem
	                        labelCol={{ span: 3 }}
	                        wrapperCol={{ span: 18 }}
	                        label="首页展示图片:" >
	                        <div className="clearfix">
	                            <Upload className="demandDetailShow-upload"
	                                listType="picture-card"
	                                fileList={this.state.coverImg}
	                                onPreview={(file) => {
	                                    this.setState({
	                                        previewImage: file.url || file.thumbUrl,
	                                        previewVisible: true,
	                                    });
	                                }} >	                               
	                            </Upload>
	                            <Modal maskClosable={false} footer={null}
	                                visible={this.state.previewVisible}
	                                onCancel={() => { this.setState({ previewVisible: false }) }}>
	                                <img alt="" style={{ width: '100%' }} src={this.state.previewImage || ''} />
	                            </Modal>
	                        </div>
	                   	 </FormItem>
                    </div> :<div></div>}                
                    <div>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主名称" >
                            <span>{theData.employerName}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="联系电话" >
                            <span>{theData.employerContactsMobile}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求联系人" >
                            <span>{theData.contacts}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求联系人电话" >
                            <span>{theData.contactMobile}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="电子邮箱" >
                            <span>{theData.employerContactsMailbox}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="通讯地址" >
                            <span>{theData.employerAddress}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="负责人" >
                            <span>{this.props.techBrodersObj[theData.techBrokerId]}</span>
                        </FormItem>
                    </div> 
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="发布时间" >
                            <span>{theData.releaseDateFormattedDate}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="信息来源" >
                            {(() => {
                                switch (theData.infoSources) {
                                    case "0":
                                        return <span>平台采集</span>;
                                    case "1":
                                        return <span>客户发布</span>;
                                    case "2":
                                        return <span>批量导入</span>;
                                    case "3":
                                        return <span>三方对接</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="加急天数" >
                        <span>{theData.urgentDays}</span>
                    </FormItem>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="加急报酬" >
                        <span>{theData.urgentMoney}</span>
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求状态" >
                            {(() => {
                                switch (theData.status) {
                                    case "0":
                                        return <span>未解决</span>;
                                    case "1":
                                        return <span>已解决</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="审核状态" >
                            {(() => {
                                switch (theData.auditStatus) {
                                    case 0:
                                        return <span>未提交审核(草稿)</span>;
                                    case 1:
                                        return <span>提交审核</span>;
                                    case 2:
                                        return <span>审核中</span>;
                                    case 3:
                                        return <span>审核通过</span>;
                                    case 4:
                                        return <span>审核未通过</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 20 }}
                        label="关键词" >
                        {this.state.tags.map((tag) => {
                            return <Tooltip key={tag} title={tag}>
                                <Tag key={tag}>{tag}</Tag>
                            </Tooltip>;
                        })}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="行业类别" >
                        <span>{getIndustryCategory(theData.industryCategoryA, theData.industryCategoryB)}</span>
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求类型" >
                            <span>{getDemandType(theData.demandType)}</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="问题说明" >
                        <span>{theData.problemDes}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="备注" >
                        <span>{theData.remark}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="技术指标要求" >
                        <span>{theData.technicalRequirements}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="需求文件(图片)" >
                        <div className="clearfix">
                            <Upload className="demandDetailShow-upload"
                                listType="picture-card"
                                fileList={this.state.pictureUrl}
                                onPreview={(file) => {
                                    this.setState({
                                        previewImage: file.url || file.thumbUrl,
                                        previewVisible: true,
                                    });
                                }} >
                            </Upload>
                            <Modal maskClosable={false} footer={null}
                                visible={this.state.previewVisible}
                                onCancel={() => { this.setState({ previewVisible: false }) }}>
                                <img alt="" style={{ width: '100%' }} src={this.state.previewImage || ''} />
                            </Modal>
                        </div>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 6 }}
                        label="需求文件(文本)" >
                        <div>{theData.textFileUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/admin/demand/download?id=' + this.props.data.id) }}>需求文件(文本文件)</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</div>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="需求文件(视频地址)" >
                        <span>{theData.videoUrl}</span>
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="固定周期" >
                            <span>{theData.fixedCycle}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="固定人数" >
                            <span>{theData.peopleNumber || 0} 人</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="固定方案" >
                        <span>{theData.fixedScheme}</span>
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="预算费用" >
                            <span>{theData.budgetCost || 0} 万元</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="费用托管" >
                            {(() => {
                                switch (theData.costEscrow) {
                                    case 0:
                                        return <span>否</span>;
                                    case 1:
                                        return <span>是</span>;
                                }
                            })()}
                        </FormItem>
                       
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="有效期限" >
                            <span>{theData.validityPeriodFormattedDate}</span>
                        </FormItem>
                    </div>
                    {window.showAuditStatus && theData.auditStatus == 2 ? <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="审核状态" >
                            {getFieldDecorator('auditStatus')(
                                <Radio.Group>
                                    <Radio value={3}>审核通过</Radio>
                                    <Radio value={4}>审核未通过</Radio>
                                </Radio.Group>
                            )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="技术经纪人" >
                            {getFieldDecorator('techBrokerId', {
                                initialValue: theData.techBrokerId
                            })(
                                <Select style={{ width: 260 }}
                                    placeholder="请选择技术经纪人"
                                    notFoundContent="未获取到经纪人列表"
                                    showSearch
                                    filterOption={companySearch}>
                                    {this.props.techBrodersOption}
                                </Select>
                                )}
                        </FormItem>
                    </div> : <div></div>}
                    {window.showAuditStatus && theData.auditStatus == 3 ? <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="指派新经纪人" >
                            {getFieldDecorator('modifyTechBrokerId', {
                                initialValue: theData.techBrokerId
                            })(
                                <Select style={{ width: 260 ,"display":"none"}}
                                    placeholder="请选择要指派的新经纪人"
                                    notFoundContent="未获取到经纪人列表"
                                    showSearch
                                    filterOption={companySearch}>
                                    {this.props.techBrodersOption}
                                </Select>
                                )}
                        </FormItem>
                    </div> : <div></div>}
                    <FormItem wrapperCol={{ span: 12, offset: 3 }}>
                        {theData.auditStatus == 2 ? <Button className="set-submit" type="primary" htmlType="submit">提交审核</Button> : <span></span>}
                        {theData.auditStatus == 3 ? <Button className="set-submit" type="primary" onClick={() => { this.modifyBroker(); }} style={{"display":"none"}}>保存</Button> : <span></span>}
                        {theData.auditStatus == 2 ? <Button className="set-submit" type="ghost" onClick={this.props.closeDesc}>取消</Button>: <span></span>}
                        {theData.auditStatus == 3? <Button className="set-submit" loading={this.state.buttonLoading} type="primary" onClick={this.buildMatchList} >生成匹配列表</Button> : <span></span>}
                    </FormItem>
                    <Modal maskClosable={false} title="确认"
                        visible={this.state.formSubmitVisible}
                        width='360px'
                        footer={null}
                        onCancel={() => { this.setState({ formSubmitVisible: false }) }} >
                        <span>确认该需求审核未通过？</span>
                        <Button className="modal-submit" type="primary" onClick={this.formSubmit}>确认</Button>
                        <Button className="modal-submit" type="ghost" onClick={() => { this.setState({ formSubmitVisible: false }) }}>取消</Button>
                    </Modal>
                </Spin>
            </Form >
        )
    }
}));

const DemandDetailForm = Form.create()(React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false,
            auditStatus: 0,
            switchValue: false,
            radios: false,
            textFileList: [],
            videoFileList: [],
            contactsOption: [],
            data: {},
            tags: [],
            pictureUrl: [],
            coverImg:[],
            dataSource: []
        };
    },
    getContactsList(theUid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/getContacts",
            data: {
                uid: theUid
            },
            success: function (data) {
                let theOption = [];
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                        return;
                    };
                };
                for (let item in data.data) {
                    let theData = data.data[item];
                    theOption.push(
                        <Select.Option value={item} key={theData}>{theData}</Select.Option>
                    );
                };
                this.setState({
                    contactsOption: theOption
                });
            }.bind(this),
        });
    },
    loadData(id, detailApiUrl,dataCategory) {
    	this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + detailApiUrl,
            data: {
                id: id,
                dataCategory:(dataCategory>=0)?dataCategory:this.props.data.dataCategory
            },
            success: function (data) {
                let thisData = data.data;
                if (!thisData) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                    thisData = {};
                };
                if (thisData.employerId) {
                    this.getContactsList(thisData.employerId)
                };
                this.setState({
                    data: thisData,
                    dataCategory:(thisData.dataCategory>-1)?thisData.dataCategory.toString():'',
                    switchValue: Boolean(!thisData.employerId),
                    radios: thisData.hot == '1' ? true : false,
                    tags: thisData.keyword ? (thisData.keyword.replace(/(，|、)/g, ",")).split(',') : [],
                    pictureUrl: thisData.pictureUrl ? splitUrl(thisData.pictureUrl, ',', globalConfig.avatarHost + '/upload') : [],
                    coverImg: thisData.coverImg ? splitUrl(thisData.coverImg, ',', globalConfig.avatarHost + '/upload') : []
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getTagsArr(e) {
        this.setState({ tags: e });
    },
    getPictureUrl(e) {
        this.setState({ pictureUrl: e });
    },
     getcoverImg(e) {
        this.setState({ coverImg: e });
    },
    handleSubmit(e) {
        e.preventDefault();
        if(!this.state.dataCategory){
    		message.warning('请选择需求类别');
    		return false;
    	}
        this.props.form.validateFields((err, values) => {
            //keyword长度判断
            if ((this.state.tags ? this.state.tags.length : this.props.tags.length) < 3) {
                message.warning('关键词数量不能小于3个！');
                return;
            };
            //url转化
            let thePictureUrl = [];
            if (this.state.pictureUrl.length) {
                let picArr = [];
                this.state.pictureUrl.map(function (item) {
                    if ( item.response && item.response.data && item.response.data.length ){
                        picArr.push(item.response.data);
                    }
                });
                thePictureUrl = picArr.join(",");
            };
            let thecoverImg = [];
            if (this.state.coverImg.length) {
                let picArr = [];
                this.state.coverImg.map(function (item) {
                    if ( item.response && item.response.data && item.response.data.length ){
                        picArr.push(item.response.data);
                    }
                });
                thecoverImg = picArr.join(",");
            };
            if (!err) {
                this.setState({
                    loading: true
                });
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: this.props.data.id ? globalConfig.context + '/api/admin/demand/update' : globalConfig.context + '/api/admin/demand/apply',
                    data: {
                        id: this.props.data.id,
                        dataCategory: this.state.dataCategory,//this.props.detailApiUrl.indexOf('org') >= 0 ? 1 : 0
                        serialNumber: this.props.data.serialNumber,
                        name: values.name,
                        keyword: this.state.tags ? this.state.tags.join(",") : this.props.tags.join(","),
                        keywords: this.state.tags ? this.state.tags : this.props.tags,
                        infoSources: 0,
                        industryCategoryA: values.industryCategory ? values.industryCategory[0] : undefined,
                        industryCategoryB: values.industryCategory ? values.industryCategory[1] : undefined,
                        demandType: values.demandType,
                        problemDes: values.problemDes,
                        remark: values.remark,
                        technicalRequirements: values.technicalRequirements,
                        pictureUrl: thePictureUrl,
                        coverImg: thecoverImg,
                        textFileUrl: this.state.textFileUrl,
                        videoUrl: values.videoUrl,
                        fixedBudget: values.fixedBudget,
                        fixedCycle: values.fixedCycle,
                        peopleNumber: values.peopleNumber,
                        fixedScheme: values.fixedScheme,
                        costEscrow: values.costEscrow,                        
                        budgetCost: values.budgetCost,
                        //
                        switchSign: 1,
                        //
                        employerId: !this.state.switchValue ? (this.state.dataSourceObj ? this.state.dataSourceObj[values.employerId] : this.props.data.employerId) : null,
                        
                        //自定义
                        contacts:values.contacts,
                        contactMobile:values.contactMobile,
                        employerName:values.employerName ,
                        urgentDays:values.urgentDays,
                        urgentMoney:values.urgentMoney ,
                        employerAddress:values.employerAddress,
                        employerContactsMobile:values.employerContactsMobile,
                        employerContactsMailbox:values.employerContactsMailbox ,
                        //
                        releaseStatus: values.releaseStatus,
                        principalId: values.principalId,
                        validityPeriodFormattedDate: values.validityPeriod ? values.validityPeriod.format('YYYY-MM-DD') : undefined,
                        //
                        status: this.state.status,
                        auditStatus: this.state.auditStatus,
                        boutique: values.boutique, 
                        hot: values.hot,                         
                    }
                }).done(function (data) {
                    this.state.auditStatus = 0;
                    if (!data.error.length) {
                        message.success('保存成功！');
                        this.props.handleOk();
                        this.componentWillMount();
                    } else {
                        message.warning(data.error[0].message);
                    };
                    this.setState({
                        loading: false
                    });
                }.bind(this));
            }
        });
    },
    handleSearch(e) {
        if (this.props.detailApiUrl.indexOf('org') != -1) {
            $.ajax({
                method: "get",
                dataType: "json",
                crossDomain: false,
                url: globalConfig.context + "/api/admin/achievement/orgOwner",
                data: { name: e },
                success: function (data) {
                    let theArr = [];
                    let theObj = {};
                    if (!data.data) {
                        if (data.error && data.error.length) {
                            message.warning(data.error[0].message);
                        };
                    } else if (!$.isEmptyObject(data.data)) {
                        data.data.map(function (item) {
                            theArr.push(item.unitName);
                            theObj[item.unitName] = item.uid;
                        });
                    };
                    this.setState({
                        dataSource: theArr,
                        dataSourceObj: theObj
                    });
                }.bind(this),
            });
        } else {
            $.ajax({
                method: "get",
                dataType: "json",
                crossDomain: false,
                url: globalConfig.context + "/api/admin/achievement/userOwner",
                data: { name: e },
                success: function (data) {
                    let theArr = [];
                    let theObj = {};
                    if (!data.data) {
                        if (data.error && data.error.length) {
                            message.warning(data.error[0].message);
                        };
                    } else if (!$.isEmptyObject(data.data)) {
                        for (let item in data.data) {
                            theArr.push(data.data[item]);
                            theObj[data.data[item]] = item;
                        };
                    };
                    this.setState({
                        dataSource: theArr,
                        dataSourceObj: theObj
                    });
                }.bind(this),
            });
        };
    },
    componentWillMount() {
        this.state.therottleSearch = throttle(this.handleSearch, 1000, { leading: false }).bind(this);
        if (this.props.data && this.props.data.id) {
            this.loadData(this.props.data.id, this.props.detailApiUrl);
        };
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            if (nextProps.data && nextProps.data.id) {
                this.loadData(nextProps.data.id, nextProps.detailApiUrl,nextProps.data.dataCategory);
            };
            this.state.contactsOption = [];
            this.state.data = {};
            this.state.tags = [];
            this.state.switchValue = false;
            this.state.radios = false;
            this.state.pictureUrl = [];
            this.state.coverImg = [];
            this.state.textFileList = [];
            this.state.videoFileList = [];
            this.state.textFileUrl = undefined;
            this.props.form.resetFields();
            this.state.dataCategory = undefined;
        };
    },
    render() {
        const theData = this.state.data || {};
        const { getFieldDecorator } = this.props.form;
        const FormItem = Form.Item
        const formItemLayout = {
            labelCol: { span: 6 },
            wrapperCol: { span: 12 },
        };
        return (
            <Form horizontal onSubmit={this.handleSubmit} id="demand-form">
                <Spin spinning={this.state.loading}>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="编号" >
                            <span>{theData.serialNumber}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求名称" >
                            {getFieldDecorator('name', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.name
                            })(
                                <Input />
                                )}
                        </FormItem>
                    </div>
                    <div>
                    	 <FormItem className="half-item"
                                {...formItemLayout}
                                label="精品需求" >
                                {getFieldDecorator('boutique', {
                                    initialValue: theData.boutique
                                })(
                                    <Radio.Group>
                                        <Radio value="0">否</Radio>
                                        <Radio value="1">是</Radio>
                                    </Radio.Group>
                                    )}
                        </FormItem>
                    </div>
                    {this.state.radios==true ? <div>
                    	<FormItem
	                        labelCol={{ span: 3 }}
	                        wrapperCol={{ span: 18 }}
	                        label="首页展示图片:" >
	                        <PicturesWall
	                            pictureSign='demand_cover_picture'
	                            uid={theData.employerId}
	                            fileList={this.getcoverImg}
	                            pictureUrl={this.state.coverImg}
	                            visible={this.props.visible} 	                        
	                            />
	                        <span>尺寸为:320x160(像素)</span>
	                    </FormItem>
	                    
                    </div> :<div></div>}
                    <div className="clearfix" >
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主名称" >
                            {getFieldDecorator('employerName', {
                                initialValue: theData.employerName
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主电话" >
                            {getFieldDecorator('employerContactsMobile', {
                                initialValue: theData.employerContactsMobile
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求联系人" >
                            {getFieldDecorator('contacts', {
                                initialValue: theData.contacts
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求联系人电话" >
                            {getFieldDecorator('contactMobile', {
                                initialValue: theData.contactMobile
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="电子邮箱" >
                            {getFieldDecorator('employerContactsMailbox', {
                                initialValue: theData.employerContactsMailbox
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="通讯地址" >
                            {getFieldDecorator('employerAddress', {
                                initialValue: theData.employerAddress
                            })(
                                <Input />
                                )}
                        </FormItem>
                    </div> 
                    <div className="clearfix">
                        {theData.techBrokerId ? <FormItem className="half-item"
                            {...formItemLayout}
                            label="负责人" >
                            <span>{this.props.techBrodersObj[theData.techBrokerId]}</span>
                        </FormItem> : <div></div>}
                    </div>
                    {theData.releaseStatus ? <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="是否发布" >
                            {(() => {
                                switch (theData.releaseStatus) {
                                    case "0":
                                        return <span>未发布</span>;
                                    case "1":
                                        return <span>已发布</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="发布时间" >
                            <span>{theData.releaseDateFormattedDate}</span>
                        </FormItem>
                    </div> : <div></div>}
                    <div className="clearfix">
                        {theData.releaseStatus == "1" ? <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求状态" >
                            {getFieldDecorator('status', {
                                initialValue: theData.status
                            })(
                                <Radio.Group>
                                    <Radio value="0">未解决</Radio>
                                    <Radio value="1">已解决</Radio>
                                </Radio.Group>
                                )}
                        </FormItem> : <div></div>}
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="审核状态" >
                            <span>{getTechAuditStatus(theData.auditStatus)}</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 20 }}
                        label="关键词" >
                        <KeyWordTagGroup
                            keyWordArr={this.state.tags}
                            tagsArr={this.getTagsArr}
                            visible={this.props.visible} />
                    </FormItem>
                    
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="需求类别" >
                        <Select placeholder="选择需求类别" 
                            value={this.state.dataCategory}
                            onChange={(e) => { this.setState({ dataCategory: e }) }}>
                            <Select.Option value="0" >个人</Select.Option>
                            <Select.Option value="1" >组织</Select.Option>
                        </Select>
                        
                    </FormItem>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="行业类别" >
                        {getFieldDecorator('industryCategory', {
                            rules: [{ type: 'array', required: true, message: '此项为必填项!' }],
                            initialValue: [theData.industryCategoryA, theData.industryCategoryB]
                        })(
                            <Cascader options={IndustryObject} placeholder="请选择一个行业" />
                            )}
                    </FormItem>
                    <FormItem className="half-item"
                            {...formItemLayout}
                            label="加急天数" >
                            {getFieldDecorator('urgentDays', {
                                initialValue: theData.urgentDays
                            })(
                                <Input style={{width:'95%'}}/>
                                )}
                            <span>天</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="加急报酬" >
                            {getFieldDecorator('urgentMoney', {
                                initialValue: theData.urgentMoney
                            })(
                                <Input  style={{width:'95%'}}/>
                                )}
                            <span>万</span>
                        </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="需求类型" >
                            {getFieldDecorator('demandType', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.demandType
                            })(
                                <Select  placeholder="请选择需求类型">
                                    {this.props.demandTypeOption}
                                </Select>
                                )}
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="问题说明" >
                        {getFieldDecorator('problemDes', {
                            rules: [{ required: true, message: '此项为必填项!' }],
                            initialValue: theData.problemDes
                        })(
                            <Input type="textarea" rows={4} />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="备注" >
                        {getFieldDecorator('remark', {
                            initialValue: theData.remark
                        })(
                            <Input type="textarea" rows={4} />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="技术指标要求" >
                        {getFieldDecorator('technicalRequirements', {
                            initialValue: theData.technicalRequirements
                        })(
                            <Input type="textarea" rows={2} />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="需求文件(图片)" >
                        <PicturesWall
                            pictureSign="demand_picture"
                            uid={theData.employerId}
                            fileList={this.getPictureUrl}
                            pictureUrl={this.state.pictureUrl}
                            visible={this.props.visible} />
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 6 }}
                        label="需求文件(文本)" >
                        <Upload
                            name="ratepay"
                            action={globalConfig.context + "/api/admin/demand/uploadTextFile"}
                            data={{ 'sign': 'demand_text_file', 'uid': theData.employerId }}
                            beforeUpload={beforeUploadFile}
                            fileList={this.state.textFileList}
                            onChange={(info) => {
                                if (info.file.status !== 'uploading') {
                                    
                                }
                                if (info.file.status === 'done') {
                                    if (!info.file.response.error.length) {
                                        message.success(`${info.file.name} 文件上传成功！`);
                                    } else {
                                        message.warning(info.file.response.error[0].message);
                                        return;
                                    };
                                    this.state.textFileUrl = info.file.response.data;
                                } else if (info.file.status === 'error') {
                                    message.error(`${info.file.name} 文件上传失败。`);
                                };
                                this.setState({ textFileList: info.fileList.slice(-1) });
                            }} >
                            <Button><Icon type="upload" /> 上传需求文本文件 </Button>
                        </Upload>
                        <p style={{ marginTop: '10px' }}>{theData.textFileUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/admin/demand/download?id=' + this.props.data.id) }}>需求文件(文本文件)</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="需求文件(视频地址)" >
                        {getFieldDecorator('videoUrl', {
                            initialValue: theData.videoUrl
                        })(
                            <Input />
                            )}
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="固定周期" >
                            {getFieldDecorator('fixedCycle', {
                                initialValue: theData.fixedCycle
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="固定人数" >
                            {getFieldDecorator('peopleNumber', {
                                initialValue: theData.peopleNumber || 0
                            })(
                                <InputNumber />
                                )}
                            <span style={{ marginLeft: '20px' }}>人</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 3 }}
                        wrapperCol={{ span: 18 }}
                        label="固定方案" >
                        {getFieldDecorator('fixedScheme', {
                            initialValue: theData.fixedScheme
                        })(
                            <Input type="textarea" rows={2} />
                            )}
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="预算费用" >
                            {getFieldDecorator('budgetCost', {
                                initialValue: theData.budgetCost || 0
                            })(
                                <InputNumber min={0} max={999999} step={0.01} />
                                )}
                            <span style={{ marginLeft: '20px' }}>万元</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="费用托管" >
                            {getFieldDecorator('costEscrow', {
                                initialValue: theData.costEscrow
                            })(
                                <Radio.Group>
                                    <Radio value={0}>否</Radio>
                                    <Radio value={1}>是</Radio>
                                </Radio.Group>
                                )}
                        </FormItem>
                       
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="有效期限" >
                            {getFieldDecorator('validityPeriod', {
                                initialValue: theData.validityPeriod ? moment(theData.validityPeriod) : null
                            })(
                                <DatePicker />
                                )}
                        </FormItem>
                    </div>
                    <div className="clearfix" style={{ display: 'none' }}>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主地址" >
                            <span>{theData.employerAddress}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主联系人名称" >
                            <span>{theData.employerContacts}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主联系人电话" >
                            <span>{theData.employerContactsMobile}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="雇主联系人邮箱" >
                            <span>{theData.employerContactsMailbox}</span>
                        </FormItem>
                    </div>
                    <FormItem wrapperCol={{ span: 12, offset: 3 }}>
                        {(theData.auditStatus != 2)? <Button className="set-submit" type="primary" htmlType="submit">保存草稿</Button>: <span></span>}
                        <Button className="set-submit" type="ghost" onClick={(e) => { this.state.auditStatus = 1; }} htmlType="submit">提交审核</Button>
                        <Button className="set-submit" type="ghost" onClick={this.props.closeDesc}>取消</Button>
                    </FormItem>
                </Spin>
            </Form >
        )
    }
}));

const DemandDetail = React.createClass({
    getInitialState() {
        return {
            visible: false,
            techBrodersObj: {},
            tabsKey: "1",
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '名称',
                    dataIndex: 'name',
                    key: 'name',
                }, {
                    title: '关键字',
                    dataIndex: 'keyword',
                    key: 'keyword',
                }, {
                    title: '类型',
                    dataIndex: 'category',
                    key: 'category',
                    render: text => { return getAchievementCategory(text); }
                }, {
                    title: '所有人名称',
                    dataIndex: 'theName',
                    key: 'theName',
                }, {
                    title: '所有人类型',
                    dataIndex: 'ownerType',
                    key: 'ownerType',
                    render: text => {
                        switch (text) {
                            case "0":
                                return <span>个人</span>;
                            case "1":
                                return <span>组织</span>
                        }
                    }
                }, {
                    title: '发布时间',
                    dataIndex: 'releaseDateFormattedDate',
                    key: 'releaseDateFormattedDate',
                }
            ],
            dataSource: [],
        };
    },
    getTechBrodersList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/audit/techBroders",
            success: function (data) {
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    }
                    return;
                };
                let _me = this, theArr = [];
                for (var item in data.data) {
                    theArr.push(
                        <Select.Option key={item}>{data.data[item]}</Select.Option>
                    )
                };
                this.setState({
                    techBrodersOption: theArr,
                    techBrodersObj: data.data
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getTableList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/demand/achievementDemand",
            data: { id: this.props.data.id },
            success: function (data) {
                let theArr = [];
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else if (data.data.length) {
                    for (let i = 0; i < data.data.length; i++) {
                        let thisdata = data.data[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            dataCategory: thisdata.dataCategory,
                            name: thisdata.name,
                            keyword: thisdata.keyword,
                            category: thisdata.category,
                            ownerType: thisdata.ownerType,
                            theName: thisdata.username || thisdata.unitName,
                            releaseDate: thisdata.releaseDate,
                            releaseDateFormattedDate: thisdata.releaseDateFormattedDate
                        });
                    };
                };
                this.setState({
                    dataSource: theArr,
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    tableRowClick(record, index) {
    	
        window.open(globalConfig.context + '/portal/detail/achievementDetail.html?id=' + record.id + '&type=' + record.ownerType);
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    handleOk(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false, true);
    },
    componentWillMount() {
        this.getTechBrodersList();
    },
    componentWillReceiveProps(nextProps) {
        if (!this.state.visible && nextProps.showDesc) {
            this.state.tabsKey = "1";
        };
        this.state.visible = nextProps.showDesc;
    },
    render() {
        if (this.props.data) {
            return (
                <div className="patent-desc">
                    <Modal maskClosable={false} visible={this.state.visible}
                        onOk={this.checkPatentProcess} onCancel={this.handleCancel}
                        width='1000px'
                        footer=''
                        className="admin-desc-content">
                        <Spin spinning={this.state.loading}>
                            <Tabs activeKey={this.state.tabsKey}
                                onChange={(e) => {
                                    this.setState({ tabsKey: e });
                                    if (e == "2") {
                                        this.getTableList();
                                    };
                                }} >
                                <Tabs.TabPane tab="需求详情" key="1">
                                    {(() => {
                                        if (this.props.data.id && this.props.data.auditStatus != "0" && this.props.data.auditStatus != "4"&& this.props.data.auditStatus != "2") {
                                            return <DemandDetailShow
                                                data={this.props.data}
                                                detailApiUrl={this.props.detailApiUrl}
                                                techBrodersOption={this.state.techBrodersOption}
                                                techBrodersObj={this.state.techBrodersObj}
                                                demandTypeOption={this.props.demandTypeOption}
                                                closeDesc={this.handleCancel}
                                                visible={this.state.visible}
                                                handleOk={this.handleOk} />
                                        } else {
                                            return <DemandDetailForm
                                                data={this.props.data}
                                                detailApiUrl={this.props.detailApiUrl}
                                                companyOption={this.props.companyOption}
                                                userOption={this.props.userOption}
                                                techBrodersObj={this.state.techBrodersObj}
                                                demandTypeOption={this.props.demandTypeOption}
                                                closeDesc={this.handleCancel}
                                                visible={this.state.visible}
                                                handleOk={this.handleOk} />
                                        }
                                    })()}
                                </Tabs.TabPane>
                                <Tabs.TabPane tab="匹配列表" key="2" disabled={!this.props.data.id}>
                                    <Table columns={this.state.columns}
                                        dataSource={this.state.dataSource}
                                        pagination={false}
                                        onRowClick={this.tableRowClick} />
                                </Tabs.TabPane>
                            </Tabs>
                        </Spin>
                    </Modal>
                </div>
            );
        } else {
            return <div></div>
        }
    },
});

export default DemandDetail;